@@ -54,7 +54,7 @@ class _PhysicalBase(Foreground):
         b = [p[f"b{i}"] for i in range(4)]
         alpha = p["ion_spec_index"]
 
-        x = np.exp(-b[3] * self.f ** alpha)
+        x = np.exp(-b[3] * self.f**alpha)
         return b[0] * self.f ** (b[1] + b[2] * np.log(self.f) - 2.5) * x, x
 
 
@@ -84,7 +84,7 @@ class PhysicalSmallIonDepth(_PhysicalBase):
     def model(self, **p):
         first_term, x = super().model(p)
         b4 = p["b4"]
-        return first_term + b4 / self.f ** 2
+        return first_term + b4 / self.f**2
 
     # Possible derived quantities
     def Te(self, ctx, **params):
@@ -98,16 +98,16 @@ class PhysicalLin(Foreground):
     """
 
     base_parameters = [Parameter("p0", fiducial=1750, latex=r"p_0")] + [
-        Parameter(f"p{i}", fiducial=0, latex=fr"p_{i}") for i in range(1, 5)
+        Parameter(f"p{i}", fiducial=0, latex=rf"p_{i}") for i in range(1, 5)
     ]
 
     def model(self, **p):
         p = [p[f"p{i}"] for i in range(5)]
 
         return (
-            self.f ** -2.5 * (p[0] + np.log(self.f) * (p[1] + p[2] * np.log(self.f)))
-            + p[3] * self.f ** -4.5
-            + p[4] * self.f ** -2
+            self.f**-2.5 * (p[0] + np.log(self.f) * (p[1] + p[2] * np.log(self.f)))
+            + p[3] * self.f**-4.5
+            + p[4] * self.f**-2
         )
 
     # Possible derived parameters
@@ -143,7 +143,7 @@ class IonContrib(Foreground):
     ]
 
     def model(self, **p):
-        return p["absorption"] * self.f ** -4.5 + p["emissivity"] * self.f ** -2
+        return p["absorption"] * self.f**-4.5 + p["emissivity"] * self.f**-2
 
 
 @attr.s
@@ -188,7 +188,7 @@ class LinLog(Foreground):
 
         # First create the parameters.
         for i in range(2, self.poly_order):
-            p.append(Parameter(f"p{i}", 0, latex=fr"p_{i}"))
+            p.append(Parameter(f"p{i}", 0, latex=rf"p_{i}"))
         return tuple(p)
 
     @cached_property
@@ -197,7 +197,7 @@ class LinLog(Foreground):
 
     @cached_property
     def basis(self):
-        return np.array([self.logf ** i for i in range(self.poly_order)])
+        return np.array([self.logf**i for i in range(self.poly_order)])
 
     def model(self, **p):
         pp = [p[f"p{i}"] for i in range(self.poly_order)]
@@ -270,7 +270,7 @@ class LinPoly(LinLog):
             if key == "beta":
                 continue
             i = int(key[1:])
-            terms.append(val * self.f ** i)
+            terms.append(val * self.f**i)
 
         return np.sum(terms, axis=0) * self.f ** p["beta"]
 
@@ -293,7 +293,7 @@ class Bias(Component):
 
         # First create the parameters.
         for i in range(1, self.poly_order):
-            p.append(Parameter(f"b{i}", 0, latex=fr"b_{i}"))
+            p.append(Parameter(f"b{i}", 0, latex=rf"b_{i}"))
         return tuple(p)
 
     def evaluate_poly(self, **params):
@@ -304,7 +304,7 @@ class Bias(Component):
         res = 0
         for i in range(self.poly_order):
             p = params[f"b{i}"]
-            res += p * x ** i
+            res += p * x**i
 
         return res
 
@@ -343,7 +343,7 @@ class LogPoly(Foreground):
 
         # First create the parameters.
         for i in range(1, self.poly_order + 1):
-            p.append(Parameter(f"p{i}", 0, latex=fr"p_{i}"))
+            p.append(Parameter(f"p{i}", 0, latex=rf"p_{i}"))
         return tuple(p)
 
     @cached_property
@@ -352,7 +352,7 @@ class LogPoly(Foreground):
 
     @cached_property
     def basis(self):
-        return np.array([self.logf ** i for i in range(self.poly_order + 1)])
+        return np.array([self.logf**i for i in range(self.poly_order + 1)])
 
     def model(self, **p):
         pp = [p[f"p{i}"] for i in range(self.poly_order + 1)]
